import numpy as np


def detector_coord_to_dict(detector_coord: np.ndarray):
    assert len(detector_coord.shape) == 1
    assert detector_coord.shape[2] == 3
    detector_coord = detector_coord.tolist()
    return {"u": detector_coord[0], "v": detector_coord[1]}


def position_to_dict(position: np.ndarray):
    assert len(position.shape) == 1
    assert position.shape[0] == 3
    assert position.dtype in [
        np.float32,
        np.float64,
    ], "Only np.float32 or np.float64 allowed."
    position = position.tolist()
    return {"x": position[0], "y": position[1], "z": position[2]}


def quaternion_to_dict(quaternion: np.ndarray):
    assert len(quaternion.shape) == 1
    assert quaternion.shape[0] == 4
    assert quaternion.dtype in [
        np.float32,
        np.float64,
    ], "Only np.float32 or np.float64 allowed."
    quaternion = quaternion.tolist()
    return {
        "x": quaternion[0],
        "y": quaternion[1],
        "z": quaternion[2],
        "w": quaternion[3],
    }


def dict_to_detector_coord(detector_coord_dict: dict):
    detector_coord = np.zeros(2)
    detector_coord[0] = detector_coord_dict["u"]
    detector_coord[1] = detector_coord_dict["v"]
    return detector_coord


def dict_to_position(position_dict: dict):
    position = np.zeros(3)
    position[0] = position_dict["x"]
    position[1] = position_dict["y"]
    position[2] = position_dict["z"]
    return position


def dict_to_quaternion(quaternion_dict: dict):
    quaternion = np.zeros(4)
    quaternion[0] = quaternion_dict["x"]
    quaternion[1] = quaternion_dict["y"]
    quaternion[2] = quaternion_dict["z"]
    quaternion[3] = quaternion_dict["w"]
    return quaternion


if __name__ == "__main__":
    pos = np.random.random(3).reshape((3,))
    rot = np.random.random(4).reshape((4,))

    pos_dict = position_to_dict(pos)
    rot_dict = quaternion_to_dict(rot)

    print(pos_dict)
    print(rot_dict)

    print(dict_to_position(pos_dict))
